Resources
=========

* `MIDI Association <http://midi.org/>`_ (midi.org)

* `Table of MIDI Messages <http://www.midi.org/techspecs/midimessages.php>`_
  (midi.org)

* `Tech Specs & Info <http://www.midi.org/techspecs/index.php>`_ (midi.org)



* `MIDI <http://en.wikipedia.org/wiki/MIDI>`_ (Wikipedia)

* `Essentials of the MIDI Protocol
  <https://ccrma.stanford.edu/~craig/articles/linuxmidi/misc/essenmidi.html>`_
  (Craig Stuart Sapp, CCRMA)

* `Outline of the Standard MIDI File Structure
  <http://www.ccarh.org/courses/253/handout/smf/>`_ (Craig Stuart Sapp,
  CCRMA)

* `Active Sense
  <http://www.blitter.com/~russtopia/MIDI/~jglatt/tech/midispec/sense.htm>`_
  (About the active sensing message.)

* `Active Sensing <http://www.sweetwater.com/insync/active-sensing/>`_
  (Sweetwater)

* `MIDI Technical/Programming Docs <http://home.roadrunner.com/~jgglatt/>`_
  (Jeff Glatt)

* `Standard MIDI Files <http://cnx.org/content/m15051/latest/>`_
  (cnx.org)

* `MIDI File Parsing
  <http://www.ccarh.org/courses/253/assignment/midifile/>`_ (Course
  assignment in `Music 253 <http://wiki.ccarh.org/wiki/Music_253>`_ at
  Stanford University)

* `MIDI File Format <http://www.sonicspot.com/guide/midifiles.html>`_
  (The Sonic Spot)

* `Delta time and running status <http://www.recordingblogs.com/sa/tabid/82/EntryId/44/MIDI-Part-XIII-Delta-time-and-running-status.aspx>`_
  (mic at recordingblogs.com)

* `MIDI meta messages
  <http://www.recordingblogs.com/sa/tabid/88/Default.aspx?topic=MIDI+meta+messages>`_ (recordingblog.com)

* `Meta Message
  <http://www.soundonsound.com/sos/jun03/articles/logicnotes0603.asp>`_
  (Sound On Sound)
